@@ -55,7 +55,7 @@ package Algorithm::Evolutionary::Op::EDA_step;
 
 use lib qw(../../..);
 
-our ($VERSION) = ( '$Revision: 1.5 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 1.2 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use Carp;
 
@@ -80,7 +80,6 @@ sub new {
   $self->{_eval} = shift || croak "No eval function found";
   $self->{_replacementRate} = shift || 0.5; #Default to half  replaced
   $self->{_population_size} = shift || 100; #Default
-  $self->{_alphabet} = shift || [ 0, 1]; #Default
   bless $self, $class;
   return $self;
 }
@@ -110,28 +109,6 @@ sub set {
   }
 }
 
-=head2 reset( $population )
-
-Start all over again by resetting the population
-
-=cut
-
-sub reset {
-  my $self = shift;
-  my $population = shift;
-  my $length = $population->[0]->size;
-  @$population = ();
-  my @alphabet = @{$self->{'_alphabet'}};
-  for ( my $p= 0; $p < $self->{'_population_size'}; $p++ ) {
-    my $string = '';
-    for ( my $i = 0; $i < $length; $i++ ) {
-      $string .= $alphabet[rand( @alphabet )];
-    }
-    my $new_one =  Algorithm::Evolutionary::Individual::String->fromString( $string );
-    push @$population, $new_one;
-  } 
-}
-
 =head2 apply( $population )
 
 Applies the algorithm to the population, which should have
@@ -148,9 +125,7 @@ sub apply ($) {
 
     #Evaluate only the new ones
     my $eval = $self->{_eval};
-    for my $p ( @{$pop} ) {
-      $p->evaluate( $eval) if !$p->Fitness();
-    }
+    map( $_->evaluate( $eval), @{$pop} );
     my @ranked_pop = sort { $b->{_fitness} <=> $a->{_fitness}; } @$pop;
 
     #Eliminate
@@ -160,6 +135,7 @@ sub apply ($) {
     #Check distribution of remaining pop
     my $how_many = @ranked_pop;
     my @occurrences;
+    my %alphabet;
     my $length = $pop->[0]->size;
     for my $p ( @ranked_pop ) {
       for ( my $i = 0; $i < $length; $i++ ) {
@@ -168,20 +144,19 @@ sub apply ($) {
 	}
 	my $this_value = $p->Atom($i);
 	$occurrences[$i]->{$this_value}++;
+	$alphabet{$this_value} = 1;
       }
     }
     my @wheel;
     for ( my $i = 0; $i < $length; $i++ ) {
-      for my $k (  @{$self->{'_alphabet'}} ) {
-	if ( $occurrences[$i]->{$k} ) {
-	  $occurrences[$i]->{$k} /= $how_many;
-	} else {
-	  $occurrences[$i]->{$k} = 0.05; #Minimum to avoid stagnation
-	}
+      for my $k ( keys %{$occurrences[$i]} ) {
+	$occurrences[$i]->{$k} /= $how_many;
       }
       $wheel[$i] = new Algorithm::Evolutionary::Hash_Wheel $occurrences[$i];
     }
 
+    my @alphabet = keys %alphabet;
+
     #Generate new population
     for ( my $p= 0; $p < $self->{'_population_size'} - $pringaos; $p++ ) {
       my $string = '';
@@ -211,10 +186,10 @@ L<Algorithm::Evolutionary::Op::GeneralGeneration>
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/09/30 16:01:28 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/EDA_step.pm,v 1.5 2009/09/30 16:01:28 jmerelo Exp $ 
+  CVS Info: $Date: 2009/09/13 09:04:54 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/EDA_step.pm,v 1.2 2009/09/13 09:04:54 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 1.5 $
+  $Revision: 1.2 $
 
 =cut
 
